@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_BITFIELD_MAN_H_
-#define _D_BITFIELD_MAN_H_
+#ifndef D_BITFIELD_MAN_H
+#define D_BITFIELD_MAN_H
 
 #include "common.h"
 
@@ -74,24 +74,14 @@ private:
   void ensureFilterBitfield();
 public:
   // [startIndex, endIndex)
-  class Range {
-  public:
+  struct Range {
     size_t startIndex;
     size_t endIndex;
-    Range(size_t startIndex = 0, size_t endIndex = 0):startIndex(startIndex),
-                                                      endIndex(endIndex) {}
-  
-    size_t getSize() const {
-      return endIndex-startIndex;
-    }
-
-    size_t getMidIndex() const {
-      return (endIndex-startIndex)/2+startIndex;
-    }
-
-    bool operator<(const Range& range) const {
-      return getSize() < range.getSize();
-    }
+    Range(size_t startIndex = 0, size_t endIndex = 0);
+    size_t getSize() const;
+    size_t getMidIndex() const;
+    bool operator<(const Range& range) const;    
+    bool operator==(const Range& range) const;
   };
 public:
   BitfieldMan(size_t blockLength, uint64_t totalLength);
@@ -105,10 +95,7 @@ public:
     return blockLength_;
   }
 
-  size_t getLastBlockLength() const
-  {
-    return totalLength_-blockLength_*(blocks_-1);
-  }
+  size_t getLastBlockLength() const;
 
   size_t getBlockLength(size_t index) const;
 
@@ -144,6 +131,7 @@ public:
   // affected by filter
   bool getSparseMissingUnusedIndex
   (size_t& index,
+   size_t minSplitSize,
    const unsigned char* ignoreBitfield,
    size_t ignoreBitfieldLength) const;
 
@@ -276,4 +264,4 @@ public:
 
 } // namespace aria2
 
-#endif // _D_BITFIELD_MAN_H_
+#endif // D_BITFIELD_MAN_H
