@@ -45,18 +45,25 @@
 #include "BtLeecherStateChoke.h"
 #include "PieceStorage.h"
 #include "wallclock.h"
+#include "a2functional.h"
+#include "fmt.h"
 
 namespace aria2 {
 
-static const int MAX_PEER_LIST_SIZE = 1024;
+namespace {
 
-DefaultPeerStorage::DefaultPeerStorage():
-  logger_(LogFactory::getInstance()),
-  removedPeerSessionDownloadLength_(0),
-  removedPeerSessionUploadLength_(0),
-  seederStateChoke_(new BtSeederStateChoke()),
-  leecherStateChoke_(new BtLeecherStateChoke()),
-  lastTransferStatMapUpdated_(0)
+const size_t MAX_PEER_LIST_SIZE = 1024;
+const size_t MAX_PEER_LIST_UPDATE = 100;
+
+} // namespace
+
+DefaultPeerStorage::DefaultPeerStorage()
+  : maxPeerListSize_(MAX_PEER_LIST_SIZE),
+    removedPeerSessionDownloadLength_(0),
+    removedPeerSessionUploadLength_(0),
+    seederStateChoke_(new BtSeederStateChoke()),
+    leecherStateChoke_(new BtLeecherStateChoke()),
+    lastTransferStatMapUpdated_(0)
 {}
 
 DefaultPeerStorage::~DefaultPeerStorage()
@@ -65,6 +72,7 @@ DefaultPeerStorage::~DefaultPeerStorage()
   delete leecherStateChoke_;
 }
 
+namespace {
 class FindIdenticalPeer {
 private:
   SharedHandle<Peer> peer_;
@@ -72,11 +80,12 @@ public:
   FindIdenticalPeer(const SharedHandle<Peer>& peer):peer_(peer) {}
 
   bool operator()(const SharedHandle<Peer>& peer) const {
-    return (peer_ == peer) ||
+    return (*peer_ == *peer) ||
       ((peer_->getIPAddress() == peer->getIPAddress()) &&
        (peer_->getPort() == peer->getPort()));
   }
 };
+} // namespace
 
 bool DefaultPeerStorage::isPeerAlreadyAdded(const SharedHandle<Peer>& peer)
 {
@@ -84,44 +93,48 @@ bool DefaultPeerStorage::isPeerAlreadyAdded(const SharedHandle<Peer>& peer)
                       FindIdenticalPeer(peer)) != peers_.end();
 }
 
-static size_t calculateMaxPeerListSize(const SharedHandle<BtRuntime>& btRuntime)
-{
-  if(btRuntime.isNull()) {
-    return MAX_PEER_LIST_SIZE;
-  }
-  return btRuntime->getMaxPeers() == 0 ?
-    MAX_PEER_LIST_SIZE :
-    btRuntime->getMaxPeers()+(btRuntime->getMaxPeers() >> 2);
-}
-
 bool DefaultPeerStorage::addPeer(const SharedHandle<Peer>& peer) {
   if(isPeerAlreadyAdded(peer)) {
-    if(logger_->debug()) {
-      logger_->debug("Adding %s:%u is rejected because it has been already"
-                    " added.", peer->getIPAddress().c_str(), peer->getPort());
-    }
+    A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
+                     " added.",
+                     peer->getIPAddress().c_str(), peer->getPort()));
     return false;
   }
-  size_t maxPeerListSize = calculateMaxPeerListSize(btRuntime_);
-  if(peers_.size() >= maxPeerListSize) {
-    deleteUnusedPeer(peers_.size()-maxPeerListSize+1);
+  const size_t peerListSize = peers_.size();
+  if(peerListSize >= maxPeerListSize_) {
+    deleteUnusedPeer(peerListSize-maxPeerListSize_+1);
   }
   peers_.push_front(peer);
+  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
+                   static_cast<unsigned long>(peers_.size())));
   return true;
 }
 
 void DefaultPeerStorage::addPeer(const std::vector<SharedHandle<Peer> >& peers)
 {
+  size_t added = 0;
+  size_t addMax = std::min(maxPeerListSize_, MAX_PEER_LIST_UPDATE);
   for(std::vector<SharedHandle<Peer> >::const_iterator itr = peers.begin(),
-        eoi = peers.end(); itr != eoi; ++itr) {
+        eoi = peers.end(); itr != eoi && added < addMax; ++itr) {
     const SharedHandle<Peer>& peer = *itr;
-    if(addPeer(peer)) {
-      if(logger_->debug()) {
-        logger_->debug(MSG_ADDING_PEER,
-                       peer->getIPAddress().c_str(), peer->getPort());
-      }
+    if(isPeerAlreadyAdded(peer)) {
+      A2_LOG_DEBUG(fmt("Adding %s:%u is rejected because it has been already"
+                       " added.",
+                       peer->getIPAddress().c_str(), peer->getPort()));
+      continue;
+    } else {
+      A2_LOG_DEBUG(fmt(MSG_ADDING_PEER,
+                       peer->getIPAddress().c_str(), peer->getPort()));
     }
-  }  
+    peers_.push_front(peer);
+    ++added;
+  }
+  const size_t peerListSize = peers_.size();
+  if(peerListSize >= maxPeerListSize_) {
+    deleteUnusedPeer(peerListSize-maxPeerListSize_);
+  }
+  A2_LOG_DEBUG(fmt("Now peer list contains %lu peers",
+                   static_cast<unsigned long>(peers_.size())));
 }
 
 void DefaultPeerStorage::addDroppedPeer(const SharedHandle<Peer>& peer)
@@ -142,12 +155,14 @@ const std::deque<SharedHandle<Peer> >& DefaultPeerStorage::getDroppedPeers()
   return droppedPeers_;
 }
 
+namespace {
 class FindFinePeer {
 public:
   bool operator()(const SharedHandle<Peer>& peer) const {
     return peer->unused() && peer->isGood();
   }
 };
+} // namespace
 
 SharedHandle<Peer> DefaultPeerStorage::getUnusedPeer() {
   std::deque<SharedHandle<Peer> >::const_iterator itr =
@@ -159,6 +174,7 @@ SharedHandle<Peer> DefaultPeerStorage::getUnusedPeer() {
   }
 }
 
+namespace {
 class FindPeer {
 private:
   std::string ipaddr;
@@ -171,6 +187,7 @@ public:
     return ipaddr == peer->getIPAddress() && port == peer->getPort();
   }
 };
+} // namespace
 
 SharedHandle<Peer> DefaultPeerStorage::getPeer(const std::string& ipaddr,
                                                uint16_t port) const {
@@ -188,9 +205,10 @@ size_t DefaultPeerStorage::countPeer() const {
 }
 
 bool DefaultPeerStorage::isPeerAvailable() {
-  return !getUnusedPeer().isNull();
+  return getUnusedPeer();
 }
 
+namespace {
 class CollectActivePeer {
 private:
   std::vector<SharedHandle<Peer> >& activePeers_;
@@ -205,6 +223,7 @@ public:
     }
   }
 };
+} // namespace
 
 void DefaultPeerStorage::getActivePeers
 (std::vector<SharedHandle<Peer> >& activePeers)
@@ -212,7 +231,8 @@ void DefaultPeerStorage::getActivePeers
   std::for_each(peers_.begin(), peers_.end(), CollectActivePeer(activePeers));
 }
 
-static TransferStat calculateStatFor(const SharedHandle<Peer>& peer)
+namespace {
+TransferStat calculateStatFor(const SharedHandle<Peer>& peer)
 {
   TransferStat s;
   s.downloadSpeed = peer->calculateDownloadSpeed();
@@ -221,14 +241,13 @@ static TransferStat calculateStatFor(const SharedHandle<Peer>& peer)
   s.sessionUploadLength = peer->getSessionUploadLength();
   return s;
 }
+} // namespace
 
 TransferStat DefaultPeerStorage::calculateStat()
 {
   TransferStat stat;
   if(lastTransferStatMapUpdated_.differenceInMillis(global::wallclock) >= 250) {
-    if(logger_->debug()) {
-      logger_->debug("Updating TransferStat of PeerStorage");
-    }
+    A2_LOG_DEBUG("Updating TransferStat of PeerStorage");
     lastTransferStatMapUpdated_ = global::wallclock;
     peerTransferStatMap_.clear();
     std::vector<SharedHandle<Peer> > activePeers;
@@ -257,9 +276,7 @@ TransferStat DefaultPeerStorage::calculateStat()
 
 void DefaultPeerStorage::updateTransferStatFor(const SharedHandle<Peer>& peer)
 {
-  if(logger_->debug()) {
-    logger_->debug("Updating TransferStat for peer %s", peer->getID().c_str());
-  }
+  A2_LOG_DEBUG(fmt("Updating TransferStat for peer %s", peer->getID().c_str()));
   std::map<std::string, TransferStat>::iterator itr =
     peerTransferStatMap_.find(peer->getID());
   if(itr == peerTransferStatMap_.end()) {
@@ -323,12 +340,10 @@ void DefaultPeerStorage::onReturningPeer(const SharedHandle<Peer>& peer)
 void DefaultPeerStorage::returnPeer(const SharedHandle<Peer>& peer)
 {
   std::deque<SharedHandle<Peer> >::iterator itr =
-    std::find(peers_.begin(), peers_.end(), peer);
+    std::find_if(peers_.begin(), peers_.end(), derefEqual(peer));
   if(itr == peers_.end()) {
-    if(logger_->debug()) {
-      logger_->debug("Cannot find peer %s:%u in PeerStorage.",
-                    peer->getIPAddress().c_str(), peer->getPort());
-    }
+    A2_LOG_DEBUG(fmt("Cannot find peer %s:%u in PeerStorage.",
+                     peer->getIPAddress().c_str(), peer->getPort()));
   } else {
     peers_.erase(itr);
 
