@@ -44,7 +44,7 @@
 #include "util.h"
 #include "message.h"
 #include "DownloadContext.h"
-#include "MetalinkHelper.h"
+#include "metalink_helper.h"
 #include "BinaryStream.h"
 #include "MemoryBufferPreDownloadHandler.h"
 #include "TrueRequestGroupCriteria.h"
@@ -55,6 +55,7 @@
 #include "A2STR.h"
 #include "a2functional.h"
 #include "download_helper.h"
+#include "fmt.h"
 #ifdef ENABLE_BITTORRENT
 # include "BtDependency.h"
 # include "download_helper.h"
@@ -66,8 +67,7 @@
 
 namespace aria2 {
 
-Metalink2RequestGroup::Metalink2RequestGroup():
-  logger_(LogFactory::getInstance()) {}
+Metalink2RequestGroup::Metalink2RequestGroup() {}
 
 namespace {
 class AccumulateNonP2PUri {
@@ -89,7 +89,7 @@ public:
     }
   }
 };
-}
+} // namespace
 
 namespace {
 class FindBitTorrentUri {
@@ -104,7 +104,7 @@ public:
     }
   }
 };
-}
+} // namespace
 
 void
 Metalink2RequestGroup::generate
@@ -113,7 +113,7 @@ Metalink2RequestGroup::generate
  const SharedHandle<Option>& option)
 {
   std::vector<SharedHandle<MetalinkEntry> > entries;
-  MetalinkHelper::parseAndQuery(entries, metalinkFile, option.get());
+  metalink::parseAndQuery(entries, metalinkFile, option.get());
   std::vector<SharedHandle<RequestGroup> > tempgroups;
   createRequestGroup(tempgroups, entries, option);
   SharedHandle<MetadataInfo> mi;
@@ -133,7 +133,7 @@ Metalink2RequestGroup::generate
  const SharedHandle<Option>& option)
 {
   std::vector<SharedHandle<MetalinkEntry> > entries;
-  MetalinkHelper::parseAndQuery(entries, binaryStream, option.get());
+  metalink::parseAndQuery(entries, binaryStream, option.get());
   std::vector<SharedHandle<RequestGroup> > tempgroups;
   createRequestGroup(tempgroups, entries, option);
   SharedHandle<MetadataInfo> mi(new MetadataInfo());
@@ -148,7 +148,7 @@ Metalink2RequestGroup::createRequestGroup
  const SharedHandle<Option>& option)
 {
   if(entries.empty()) {
-    logger_->notice(EX_NO_RESULT_WITH_YOUR_PREFS);
+    A2_LOG_NOTICE(EX_NO_RESULT_WITH_YOUR_PREFS);
     return;
   }
   std::vector<int32_t> selectIndexes =
@@ -191,13 +191,13 @@ Metalink2RequestGroup::createRequestGroup
                 mem_fun_sh(&MetalinkEntry::reorderMetaurlsByPriority));
   std::vector<std::pair<std::string,
     std::vector<SharedHandle<MetalinkEntry> > > > entryGroups;
-  MetalinkHelper::groupEntryByMetaurlName(entryGroups, selectedEntries);
+  metalink::groupEntryByMetaurlName(entryGroups, selectedEntries);
   for(std::vector<std::pair<std::string,
         std::vector<SharedHandle<MetalinkEntry> > > >::const_iterator itr =
         entryGroups.begin(), eoi = entryGroups.end(); itr != eoi; ++itr) {
     const std::string& metaurl = (*itr).first;
     const std::vector<SharedHandle<MetalinkEntry> >& mes = (*itr).second;
-    logger_->info("Processing metaurl group metaurl=%s", metaurl.c_str());
+    A2_LOG_INFO(fmt("Processing metaurl group metaurl=%s", metaurl.c_str()));
 #ifdef ENABLE_BITTORRENT
     SharedHandle<RequestGroup> torrentRg;
     if(!metaurl.empty()) {
@@ -212,7 +212,7 @@ Metalink2RequestGroup::createRequestGroup
           torrentRg = result[0];
         }
       }
-      if(!torrentRg.isNull()) {
+      if(torrentRg) {
         torrentRg->setNumConcurrentCommand(1);
         torrentRg->clearPreDownloadHandler();
         torrentRg->clearPostDownloadHandler();
@@ -233,7 +233,7 @@ Metalink2RequestGroup::createRequestGroup
     SharedHandle<DownloadContext> dctx;
     if(mes.size() == 1) {
       SharedHandle<MetalinkEntry> entry = mes[0];
-      logger_->info(MSG_METALINK_QUEUEING, entry->getPath().c_str());
+      A2_LOG_INFO(fmt(MSG_METALINK_QUEUEING, entry->getPath().c_str()));
       entry->reorderResourcesByPriority();
       std::vector<std::string> uris;
       std::for_each(entry->resources.begin(), entry->resources.end(),
@@ -242,7 +242,7 @@ Metalink2RequestGroup::createRequestGroup
       // make segment size equal to piece hash size.
       size_t pieceLength;
 #ifdef ENABLE_MESSAGE_DIGEST
-      if(entry->chunkChecksum.isNull()) {
+      if(!entry->chunkChecksum) {
         pieceLength = option->getAsInt(PREF_SEGMENT_SIZE);
       } else {
         pieceLength = entry->chunkChecksum->getChecksumLength();
@@ -256,16 +256,17 @@ Metalink2RequestGroup::createRequestGroup
                   util::applyDir(option->get(PREF_DIR),
                                  entry->file->getPath())));
       dctx->getFirstFileEntry()->setUris(uris);
-      dctx->getFirstFileEntry()->setMaxConnectionPerServer(1);
+      dctx->getFirstFileEntry()->setMaxConnectionPerServer
+        (option->getAsInt(PREF_MAX_CONNECTION_PER_SERVER));
       if(option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL)) {
         dctx->getFirstFileEntry()->setUniqueProtocol(true);
       }
 #ifdef ENABLE_MESSAGE_DIGEST
-      if(!entry->checksum.isNull()) {
+      if(entry->checksum) {
         dctx->setChecksum(entry->checksum->getMessageDigest());
         dctx->setChecksumHashAlgo(entry->checksum->getAlgo());
       }
-      if(!entry->chunkChecksum.isNull()) {
+      if(entry->chunkChecksum) {
         dctx->setPieceHashes(entry->chunkChecksum->getChecksums().begin(),
                              entry->chunkChecksum->getChecksums().end());
         dctx->setPieceHashAlgo(entry->chunkChecksum->getAlgo());
@@ -285,9 +286,9 @@ Metalink2RequestGroup::createRequestGroup
       off_t offset = 0;
       for(std::vector<SharedHandle<MetalinkEntry> >::const_iterator i =
             mes.begin(), eoi = mes.end(); i != eoi; ++i) {
-        logger_->info("Metalink: Queueing %s for download as a member.",
-                      (*i)->getPath().c_str());
-        logger_->debug("originalName = %s", (*i)->metaurls[0]->name.c_str());
+        A2_LOG_INFO(fmt("Metalink: Queueing %s for download as a member.",
+                        (*i)->getPath().c_str()));
+        A2_LOG_DEBUG(fmt("originalName = %s", (*i)->metaurls[0]->name.c_str()));
         (*i)->reorderResourcesByPriority();
         std::vector<std::string> uris;
         std::for_each((*i)->resources.begin(), (*i)->resources.end(),
@@ -296,7 +297,8 @@ Metalink2RequestGroup::createRequestGroup
           (new FileEntry
            (util::applyDir(option->get(PREF_DIR), (*i)->file->getPath()),
             (*i)->file->getLength(), offset, uris));
-        fe->setMaxConnectionPerServer(1);
+        fe->setMaxConnectionPerServer
+          (option->getAsInt(PREF_MAX_CONNECTION_PER_SERVER));
         if(option->getAsBool(PREF_METALINK_ENABLE_UNIQUE_PROTOCOL)) {
           fe->setUniqueProtocol(true);
         }
@@ -307,16 +309,15 @@ Metalink2RequestGroup::createRequestGroup
       dctx->setFileEntries(fileEntries.begin(), fileEntries.end());
       rg->setNumConcurrentCommand(option->getAsInt(PREF_METALINK_SERVERS));
     }
-    dctx->setDir(option->get(PREF_DIR));
     rg->setDownloadContext(dctx);
     // remove "metalink" from Accept Type list to avoid loop in
     // tranparent metalink
     util::removeMetalinkContentTypes(rg);
 #ifdef ENABLE_BITTORRENT
     // Inject depenency between rg and torrentRg here if
-    // torrentRg.isNull() == false
-    if(!torrentRg.isNull()) {
-      SharedHandle<Dependency> dep(new BtDependency(rg, torrentRg));
+    // torrentRg is true
+    if(torrentRg) {
+      SharedHandle<Dependency> dep(new BtDependency(rg.get(), torrentRg));
       rg->dependsOn(dep);
       torrentRg->belongsTo(rg->getGID());
       // metadata download may take very long time. If URIs are
