@@ -48,8 +48,6 @@
 
 namespace aria2 {
 
-class Logger;
-
 class PollEventPoll : public EventPoll {
 private:
   class KSocketEntry;
@@ -84,8 +82,6 @@ private:
 
   struct pollfd* pollfds_;
 
-  Logger* logger_;
-
   bool addEvents(sock_t socket, const KEvent& event);
 
   bool deleteEvents(sock_t socket, const KEvent& event);
