@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_REQUEST_GROUP_H_
-#define _D_REQUEST_GROUP_H_
+#ifndef D_REQUEST_GROUP_H
+#define D_REQUEST_GROUP_H
 
 #include "common.h"
 
@@ -45,7 +45,7 @@
 #include "TransferStat.h"
 #include "TimeA2.h"
 #include "Request.h"
-#include "DownloadResultCode.h"
+#include "error_code.h"
 #include "MetadataInfo.h"
 
 namespace aria2 {
@@ -62,7 +62,6 @@ class PreDownloadHandler;
 class PostDownloadHandler;
 class DiskWriterFactory;
 class Option;
-class Logger;
 class RequestGroup;
 class CheckIntegrityEntry;
 struct DownloadResult;
@@ -74,7 +73,7 @@ class BtRuntime;
 class PeerStorage;
 #endif // ENABLE_BITTORRENT
 
-typedef int64_t gid_t;
+typedef int64_t a2_gid_t;
 
 class RequestGroup {
 public:
@@ -84,9 +83,9 @@ public:
     USER_REQUEST
   };
 private:
-  static gid_t gidCounter_;
+  static a2_gid_t gidCounter_;
 
-  gid_t gid_;
+  a2_gid_t gid_;
 
   SharedHandle<Option> option_;
 
@@ -97,6 +96,8 @@ private:
    */
   unsigned int numStreamConnection_;
 
+  unsigned int numStreamCommand_;
+
   unsigned int numCommand_;
 
   SharedHandle<SegmentMan> segmentMan_;
@@ -141,9 +142,9 @@ private:
   time_t timeout_;
 
 #ifdef ENABLE_BITTORRENT
-  WeakHandle<BtRuntime> btRuntime_;
+  BtRuntime* btRuntime_;
 
-  WeakHandle<PeerStorage> peerStorage_;
+  PeerStorage* peerStorage_;
 #endif // ENABLE_BITTORRENT
 
   // This flag just indicates that the downloaded file is not saved disk but
@@ -154,19 +155,19 @@ private:
 
   unsigned int maxUploadSpeedLimit_;
 
-  SharedHandle<URIResult> lastUriResult_;
+  error_code::Value lastErrorCode_;
 
   // If this download generates another downloads when completed(for
   // example, downloads generated by PostDownloadHandler), this field
   // has the GID of generated RequestGroups. empty list means there is
   // no such RequestGroup.
-  std::vector<gid_t> followedByGIDs_;
+  std::vector<a2_gid_t> followedByGIDs_;
 
   // If this download is a part of another download(for example,
   // downloading torrent file described in Metalink file), this field
   // has the GID of parent RequestGroup. 0 means this is a parent
   // RequestGroup.
-  gid_t belongsToGID_;
+  a2_gid_t belongsToGID_;
 
   SharedHandle<MetadataInfo> metadataInfo_;
 
@@ -174,8 +175,6 @@ private:
 
   int resumeFailureCount_;
 
-  Logger* logger_;
-
   void validateFilename(const std::string& expectedFilename,
                         const std::string& actualFilename) const;
 
@@ -186,14 +185,16 @@ private:
   bool tryAutoFileRenaming();
 
   // Returns the result code of this RequestGroup.  If the download
-  // finished, then returns downloadresultcode::FINISHED.  If the
+  // finished, then returns error_code::FINISHED.  If the
   // download didn't finish and error result is available in
   // _uriResults, then last result code is returned.  Otherwise
-  // returns downloadresultcode::UNKNOWN_ERROR.
-  downloadresultcode::RESULT downloadResult() const;
+  // returns error_code::UNKNOWN_ERROR.
+  error_code::Value downloadResult() const;
 
   void removeDefunctControlFile
   (const SharedHandle<BtProgressInfoFile>& progressInfoFile);
+
+  bool isCheckIntegrityReady() const;
 public:
   // The copy of option is stored in RequestGroup object.
   RequestGroup(const SharedHandle<Option>& option);
@@ -205,6 +206,8 @@ public:
     return segmentMan_;
   }
 
+  SharedHandle<CheckIntegrityEntry> createCheckIntegrityEntry();
+
   // Returns first bootstrap commands to initiate a download.
   // If this is HTTP/FTP download and file size is unknown, only 1 command
   // (usually, HttpInitiateConnection or FtpInitiateConnection) will be created.
@@ -253,7 +256,7 @@ public:
     return numConcurrentCommand_;
   }
 
-  gid_t getGID() const
+  a2_gid_t getGID() const
   {
     return gid_;
   }
@@ -278,13 +281,14 @@ public:
 
   void setProgressInfoFile(const SharedHandle<BtProgressInfoFile>& progressInfoFile);
 
+  void increaseStreamCommand();
+
+  void decreaseStreamCommand();
+
   void increaseStreamConnection();
 
   void decreaseStreamConnection();
 
-  // Returns the number of connections used in HTTP(S)/FTP.
-  unsigned int getNumStreamConnection() { return numStreamConnection_; }
-
   unsigned int getNumConnection() const;
 
   void increaseNumCommand();
@@ -477,7 +481,10 @@ public:
     maxUploadSpeedLimit_ = speed;
   }
 
-  void setLastUriResult(std::string uri, downloadresultcode::RESULT result);
+  void setLastErrorCode(error_code::Value code)
+  {
+    lastErrorCode_ = code;
+  }
 
   void saveControlFile() const;
 
@@ -496,17 +503,17 @@ public:
     }
   }
 
-  const std::vector<gid_t>& followedBy() const
+  const std::vector<a2_gid_t>& followedBy() const
   {
     return followedByGIDs_;
   }
 
-  void belongsTo(gid_t gid)
+  void belongsTo(a2_gid_t gid)
   {
     belongsToGID_ = gid;
   }
 
-  gid_t belongsTo() const
+  a2_gid_t belongsTo() const
   {
     return belongsToGID_;
   }
@@ -540,9 +547,9 @@ public:
 
   static void resetGIDCounter() { gidCounter_ = 0; }
 
-  static gid_t newGID();
+  static a2_gid_t newGID();
 };
 
 } // namespace aria2
 
-#endif // _D_REQUEST_GROUP_H_
+#endif // D_REQUEST_GROUP_H
