@@ -32,8 +32,8 @@
  * files in the program, then also delete it here.
  */
 /* copyright --> */
-#ifndef _D_REQUEST_GROUP_MAN_H_
-#define _D_REQUEST_GROUP_MAN_H_
+#ifndef D_REQUEST_GROUP_MAN_H
+#define D_REQUEST_GROUP_MAN_H
 
 #include "common.h"
 
@@ -51,7 +51,6 @@ namespace aria2 {
 
 class DownloadEngine;
 class Command;
-class Logger;
 struct DownloadResult;
 class ServerStatMan;
 class ServerStat;
@@ -62,7 +61,6 @@ private:
   std::deque<SharedHandle<RequestGroup> > requestGroups_;
   std::deque<SharedHandle<RequestGroup> > reservedGroups_;
   std::deque<SharedHandle<DownloadResult> > downloadResults_;
-  Logger* logger_;
   unsigned int maxSimultaneousDownloads_;
 
   const Option* option_;
@@ -73,8 +71,8 @@ private:
 
   unsigned int maxOverallUploadSpeedLimit_;
 
-  // truf if XML-RPC is enabled.
-  bool xmlRpc_;
+  // true if JSON-RPC/XML-RPC is enabled.
+  bool rpc_;
 
   bool queueCheck_;
 
@@ -83,7 +81,7 @@ private:
   size_t removedErrorResult_;
 
   // The last error of removed DownloadResult
-  downloadresultcode::RESULT removedLastErrorResult_;
+  error_code::Value removedLastErrorResult_;
 
   size_t maxDownloadResult_;
 
@@ -98,6 +96,8 @@ public:
                   unsigned int maxSimultaneousDownloads,
                   const Option* option);
 
+  ~RequestGroupMan();
+
   bool downloadFinished();
 
   void save();
@@ -132,14 +132,14 @@ public:
     return requestGroups_;
   }
 
-  SharedHandle<RequestGroup> findRequestGroup(gid_t gid) const;
+  SharedHandle<RequestGroup> findRequestGroup(a2_gid_t gid) const;
 
   const std::deque<SharedHandle<RequestGroup> >& getReservedGroups() const
   {
     return reservedGroups_;
   }
 
-  SharedHandle<RequestGroup> findReservedGroup(gid_t gid) const;
+  SharedHandle<RequestGroup> findReservedGroup(a2_gid_t gid) const;
 
   enum HOW {
     POS_SET,
@@ -156,9 +156,9 @@ public:
   // beyond the end of the queue, it moves the download to the
   // beginning or the end of the queue respectively.  Returns the
   // destination position.
-  size_t changeReservedGroupPosition(gid_t gid, int pos, HOW how);
+  size_t changeReservedGroupPosition(a2_gid_t gid, int pos, HOW how);
 
-  bool removeReservedGroup(gid_t gid);
+  bool removeReservedGroup(a2_gid_t gid);
 
   void showDownloadResults(std::ostream& o) const;
 
@@ -172,21 +172,21 @@ public:
     size_t error_;
     size_t inProgress_;
     size_t waiting_;
-    downloadresultcode::RESULT lastErrorResult_;
+    error_code::Value lastErrorResult_;
   public:
     DownloadStat(size_t completed,
                  size_t error,
                  size_t inProgress,
                  size_t waiting,
-                 downloadresultcode::RESULT lastErrorResult =
-                 downloadresultcode::FINISHED):
+                 error_code::Value lastErrorResult =
+                 error_code::FINISHED):
       completed_(completed),
       error_(error),
       inProgress_(inProgress),
       waiting_(waiting),
       lastErrorResult_(lastErrorResult) {}
 
-    downloadresultcode::RESULT getLastErrorResult() const
+    error_code::Value getLastErrorResult() const
     {
       return lastErrorResult_;
     }
@@ -209,11 +209,15 @@ public:
     return downloadResults_;
   }
 
-  SharedHandle<DownloadResult> findDownloadResult(gid_t gid) const;
+  SharedHandle<DownloadResult> findDownloadResult(a2_gid_t gid) const;
 
   // Removes all download results.
   void purgeDownloadResult();
 
+  // Removes download result of given gid. Returns true if download
+  // result was removed. Otherwise returns false.
+  bool removeDownloadResult(a2_gid_t gid);
+
   void addDownloadResult(const SharedHandle<DownloadResult>& downloadResult);
 
   SharedHandle<ServerStat> findServerStat(const std::string& hostname,
@@ -293,4 +297,4 @@ typedef SharedHandle<RequestGroupMan> RequestGroupManHandle;
 
 } // namespace aria2
 
-#endif // _D_REQUEST_GROUP_MAN_H_
+#endif // D_REQUEST_GROUP_MAN_H
