@@ -40,11 +40,12 @@
 #include <cstring>
 #include <algorithm>
 #include <numeric>
-#include <iostream>
 
 #include "Command.h"
 #include "LogFactory.h"
 #include "Logger.h"
+#include "a2functional.h"
+#include "fmt.h"
 
 namespace aria2 {
 
@@ -149,7 +150,7 @@ void SelectEventPoll::AsyncNameResolverEntry::process
 
 #endif // ENABLE_ASYNC_DNS
 
-SelectEventPoll::SelectEventPoll():logger_(LogFactory::getInstance())
+SelectEventPoll::SelectEventPoll()
 {
 #ifdef __MINGW32__
   dummySocket_ = socket(AF_INET, SOCK_STREAM, IPPROTO_TCP);
@@ -226,11 +227,11 @@ void SelectEventPoll::poll(const struct timeval& tv)
 
 #ifdef __MINGW32__
 namespace {
-void checkFdCountMingw(const fd_set& fdset, Logger* logger)
+void checkFdCountMingw(const fd_set& fdset)
 {
   if(fdset.fd_count >= FD_SETSIZE) {
-    logger->warn("The number of file descriptor exceeded FD_SETSIZE. "
-                 "Download may slow down or fail.");
+    A2_LOG_WARN("The number of file descriptor exceeded FD_SETSIZE. "
+                "Download may slow down or fail.");
   }
 }
 } // namespace
@@ -250,21 +251,21 @@ void SelectEventPoll::updateFdSet()
     sock_t fd = (*i)->getSocket();
 #ifndef __MINGW32__
     if(fd < 0 || FD_SETSIZE <= fd) {
-      logger_->warn("Detected file descriptor >= FD_SETSIZE or < 0. "
-                    "Download may slow down or fail.");
+      A2_LOG_WARN("Detected file descriptor >= FD_SETSIZE or < 0. "
+                  "Download may slow down or fail.");
       continue;
     }
 #endif // !__MINGW32__
     int events = (*i)->getEvents();
     if(events&EventPoll::EVENT_READ) {
 #ifdef __MINGW32__
-      checkFdCountMingw(rfdset_, logger_);
+      checkFdCountMingw(rfdset_);
 #endif // __MINGW32__
       FD_SET(fd, &rfdset_);
     }
     if(events&EventPoll::EVENT_WRITE) {
 #ifdef __MINGW32__
-      checkFdCountMingw(wfdset_, logger_);
+      checkFdCountMingw(wfdset_);
 #endif // __MINGW32__
       FD_SET(fd, &wfdset_);
     }
@@ -279,24 +280,16 @@ bool SelectEventPoll::addEvents(sock_t socket, Command* command,
 {
   SharedHandle<SocketEntry> socketEntry(new SocketEntry(socket));
   std::deque<SharedHandle<SocketEntry> >::iterator i =
-    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry);
-  int r = 0;
-  if(i != socketEntries_.end() && (*i) == socketEntry) {
+    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry,
+                     DerefLess<SharedHandle<SocketEntry> >());
+  if(i != socketEntries_.end() && *(*i) == *socketEntry) {
     (*i)->addCommandEvent(command, events);
   } else {
     socketEntries_.insert(i, socketEntry);
     socketEntry->addCommandEvent(command, events);
   }
   updateFdSet();
-  if(r == -1) {
-    if(logger_->debug()) {
-      logger_->debug("Failed to add socket event %d:%s",
-                     socket, strerror(errno));
-    }
-    return false;
-  } else {
-    return true;
-  }
+  return true;
 }
 
 bool SelectEventPoll::deleteEvents(sock_t socket, Command* command,
@@ -304,26 +297,17 @@ bool SelectEventPoll::deleteEvents(sock_t socket, Command* command,
 {
   SharedHandle<SocketEntry> socketEntry(new SocketEntry(socket));
   std::deque<SharedHandle<SocketEntry> >::iterator i =
-    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry);
-  if(i != socketEntries_.end() && (*i) == socketEntry) {
+    std::lower_bound(socketEntries_.begin(), socketEntries_.end(), socketEntry,
+                     DerefLess<SharedHandle<SocketEntry> >());
+  if(i != socketEntries_.end() && *(*i) == *socketEntry) {
     (*i)->removeCommandEvent(command, events);
-    int r = 0;
     if((*i)->eventEmpty()) {
       socketEntries_.erase(i);
     }
     updateFdSet();
-    if(r == -1) {
-      if(logger_->debug()) {
-        logger_->debug("Failed to delete socket event:%s", strerror(errno));
-      }
-      return false;
-    } else {
-      return true;
-    }
+    return true;
   } else {
-    if(logger_->debug()) {
-      logger_->debug("Socket %d is not found in SocketEntries.", socket);
-    }
+    A2_LOG_DEBUG(fmt("Socket %d is not found in SocketEntries.", socket));
     return false;
   }
 }
@@ -335,7 +319,8 @@ bool SelectEventPoll::addNameResolver
   SharedHandle<AsyncNameResolverEntry> entry
     (new AsyncNameResolverEntry(resolver, command));
   std::deque<SharedHandle<AsyncNameResolverEntry> >::iterator itr =
-    std::find(nameResolverEntries_.begin(), nameResolverEntries_.end(), entry);
+    std::find_if(nameResolverEntries_.begin(), nameResolverEntries_.end(),
+                 derefEqual(entry));
   if(itr == nameResolverEntries_.end()) {
     nameResolverEntries_.push_back(entry);
     return true;
@@ -350,7 +335,8 @@ bool SelectEventPoll::deleteNameResolver
   SharedHandle<AsyncNameResolverEntry> entry
     (new AsyncNameResolverEntry(resolver, command));
   std::deque<SharedHandle<AsyncNameResolverEntry> >::iterator itr =
-    std::find(nameResolverEntries_.begin(), nameResolverEntries_.end(), entry);
+    std::find_if(nameResolverEntries_.begin(), nameResolverEntries_.end(),
+                 derefEqual(entry));
   if(itr == nameResolverEntries_.end()) {
     return false;
   } else {
