@@ -42,7 +42,7 @@
   _(" -l, --log=LOG                The file name of the log file. If '-' is\n" \
     "                              specified, log is written to stdout.")
 #define TEXT_DAEMON                                                     \
-  _(" -D, --daemon                 Run as daemon. The current working directory will\n" \
+  _(" -D, --daemon[=true|false]    Run as daemon. The current working directory will\n" \
     "                              be changed to \"/\" and standard input, standard\n" \
     "                              output and standard error will be redirected to\n" \
     "                              \"/dev/null\".")
@@ -52,12 +52,16 @@
     "                              remaining URLs are used for backup. If less than\n" \
     "                              N URLs are given, those URLs are used more than\n" \
     "                              once so that N connections total are made\n" \
-    "                              simultaneously. Please see -j option too.\n" \
+    "                              simultaneously. The number of connections to the\n" \
+    "                              same host is restricted by\n"        \
+    "                              --max-connection-per-server option. Please see -j\n" \
+    "                              and --min-split-size option too.\n"  \
     "                              Please note that in Metalink download, this\n" \
     "                              option has no effect and use -C option instead.")
 #define TEXT_RETRY_WAIT                                                 \
-  _(" --retry-wait=SEC             Set the seconds to wait to retry after an error\n" \
-    "                              has occured.")
+  _(" --retry-wait=SEC             Set the seconds to wait between retries. \n" \
+    "                              With SEC > 0, aria2 will retry download when the\n" \
+    "                              HTTP server returns 503 response.")
 #define TEXT_TIMEOUT                                            \
   _(" -t, --timeout=SEC            Set timeout in seconds.")
 #define TEXT_MAX_TRIES                                                  \
@@ -144,14 +148,14 @@
     "                              allocating files.\n"                 \
     "                              Turn off if you encounter any error")
 #define TEXT_ALLOW_OVERWRITE                                            \
-  _(" --allow-overwrite=true|false Restart download from scratch if the\n" \
+  _(" --allow-overwrite[=true|false] Restart download from scratch if the\n" \
     "                              corresponding control file doesn't exist.  See\n" \
     "                              also --auto-file-renaming option.")
 #define TEXT_ALLOW_PIECE_LENGTH_CHANGE                                  \
-  _(" --allow-piece-length-change=true|false If false is given, aria2 aborts download\n" \
-    "                              when a piece length is different from one in\n" \
-    "                              a control file. If true is given, you can proceed\n" \
-    "                              but some download progress will be lost.")  
+  _(" --allow-piece-length-change[=true|false] If false is given, aria2 aborts\n" \
+    "                              download when a piece length is different from\n" \
+    "                              one in a control file. If true is given, you can\n" \
+    "                              proceed but some download progress will be lost.")  
 #define TEXT_FORCE_SEQUENTIAL                                           \
   _(" -Z, --force-sequential[=true|false] Fetch URIs in the command-line sequentially\n" \
     "                              and download each URI in a separate session, like\n" \
@@ -192,11 +196,11 @@
     "                              This option has effect only on BitTorrent\n" \
     "                              download.")
 #define TEXT_REALTIME_CHUNK_CHECKSUM                                    \
-  _(" --realtime-chunk-checksum=true|false  Validate chunk of data by calculating\n" \
+  _(" --realtime-chunk-checksum[=true|false]  Validate chunk of data by calculating\n" \
     "                              checksum while downloading a file if chunk\n" \
     "                              checksums are provided.")
 #define TEXT_CONTINUE                                                   \
-  _(" -c, --continue               Continue downloading a partially downloaded\n" \
+  _(" -c, --continue[=true|false]  Continue downloading a partially downloaded\n" \
     "                              file. Use this option to resume a download\n" \
     "                              started by a web browser or another program\n" \
     "                              which downloads files sequentially from the\n" \
@@ -205,16 +209,17 @@
 #define TEXT_USER_AGENT                                                 \
   _(" -U, --user-agent=USER_AGENT  Set user agent for http(s) downloads.")
 #define TEXT_NO_NETRC                                           \
-  _(" -n, --no-netrc               Disables netrc support.")
+  _(" -n, --no-netrc[=true|false]  Disables netrc support.")
 #define TEXT_INPUT_FILE                                                 \
   _(" -i, --input-file=FILE        Downloads URIs found in FILE. You can specify\n" \
     "                              multiple URIs for a single entity: separate\n" \
     "                              URIs on a single line using the TAB character.\n" \
     "                              Reads input from stdin when '-' is specified.\n" \
-    "                              The additional out and dir options can be\n" \
-    "                              specified after each line of URIs. This optional\n" \
-    "                              line must start with white space(s). See INPUT\n" \
-    "                              FILE section of man page for details.")
+    "                              Additionally, options can be specified after each\n" \
+    "                              line of URI. This optional line must start with\n" \
+    "                              one or more white spaces and have one option per\n" \
+    "                              single line. See INPUT FILE section of man page\n" \
+    "                              for details.")
 #define TEXT_MAX_CONCURRENT_DOWNLOADS                                   \
   _(" -j, --max-concurrent-downloads=N Set maximum number of parallel downloads for\n" \
     "                              every static (HTTP/FTP) URL, torrent and metalink.\n" \
@@ -228,9 +233,10 @@
     "                              overwritten. Session Cookies are also saved and\n" \
     "                              their expiry values are treated as 0.")
 #define TEXT_SHOW_FILES                                                 \
-  _(" -S, --show-files             Print file listing of .torrent or .metalink file\n" \
-    "                              and exit. More detailed information will be listed\n" \
-    "                              in case of torrent file.")
+  _(" -S, --show-files[=true|false] Print file listing of .torrent, .meta4 and\n" \
+    "                              .metalink file and exit. More detailed\n" \
+    "                              information will be listed in case of torrent\n" \
+    "                              file.")
 #define TEXT_SELECT_FILE                                                \
   _(" --select-file=INDEX...       Set file to download by specifying its index.\n" \
     "                              You can find the file index using the\n" \
@@ -252,9 +258,6 @@
     "                              written to the disk, but is just kept in memory.\n" \
     "                              If false is specified, the action mentioned above\n" \
     "                              is not taken.")
-#define TEXT_DIRECT_FILE_MAPPING                                        \
-  _(" --direct-file-mapping=true|false Directly read from and write to each file\n" \
-    "                              mentioned in .torrent file.")
 #define TEXT_LISTEN_PORT                                                \
   _(" --listen-port=PORT...        Set TCP port number for BitTorrent downloads.\n" \
     "                              Multiple ports can be specified by using ',',\n" \
@@ -294,25 +297,25 @@
 #define TEXT_ENABLE_PEER_EXCHANGE                                       \
   _(" --enable-peer-exchange[=true|false] Enable Peer Exchange extension.")
 #define TEXT_ENABLE_DHT                                         \
-  _(" --enable-dht[=true|false]    Enable DHT functionality.")
+  _(" --enable-dht[=true|false]    Enable IPv4 DHT functionality.")
 #define TEXT_DHT_LISTEN_PORT                                            \
-  _(" --dht-listen-port=PORT...    Set UDP listening port for DHT.\n"   \
-    "                              Multiple ports can be specified by using ',',\n" \
-    "                              for example: \"6881,6885\". You can also use '-'\n" \
-    "                              to specify a range: \"6881-6999\". ',' and '-' can\n" \
-    "                              be used together.")
+  _(" --dht-listen-port=PORT...    Set UDP listening port for both IPv4 and IPv6\n"   \
+    "                              DHT. Multiple ports can be specified by using\n" \
+    "                              ',', for example: \"6881,6885\". You can also\n" \
+    "                              use '-' to specify a range: \"6881-6999\". ','\n" \
+    "                              and '-' can be used together.")
 #define TEXT_DHT_ENTRY_POINT                                            \
-  _(" --dht-entry-point=HOST:PORT  Set host and port as an entry point to DHT\n" \
+  _(" --dht-entry-point=HOST:PORT  Set host and port as an entry point to IPv4 DHT\n" \
     "                              network.")
 #define TEXT_DHT_FILE_PATH                                              \
-  _(" --dht-file-path=PATH         Change the DHT routing table file to PATH.")
+  _(" --dht-file-path=PATH         Change the IPv4 DHT routing table file to PATH.")
 #define TEXT_BT_MIN_CRYPTO_LEVEL                                        \
   _(" --bt-min-crypto-level=plain|arc4 Set minimum level of encryption method.\n" \
     "                              If several encryption methods are provided by a\n" \
     "                              peer, aria2 chooses the lowest one which satisfies\n" \
     "                              the given level.")
 #define TEXT_BT_REQUIRE_CRYPTO                                          \
-  _(" --bt-require-crypto=true|false If true is given, aria2 doesn't accept and\n" \
+  _(" --bt-require-crypto[=true|false] If true is given, aria2 doesn't accept and\n" \
     "                              establish connection with legacy BitTorrent\n" \
     "                              handshake. Thus aria2 always uses Obfuscation\n" \
     "                              handshake.")
@@ -335,8 +338,9 @@
     "                              0 means unlimited.\n"                \
     "                              See also --bt-request-peer-speed-limit option.")
 #define TEXT_METALINK_FILE                                              \
-  _(" -M, --metalink-file=METALINK_FILE The file path to the .metalink file. Reads\n" \
-    "                              input from stdin when '-' is specified.")
+  _(" -M, --metalink-file=METALINK_FILE The file path to the .meta4 and .metalink\n" \
+    "                              file. Reads input from stdin when '-' is\n" \
+    "                              specified.")
 #define TEXT_METALINK_SERVERS                                           \
   _(" -C, --metalink-servers=NUM_SERVERS The number of servers to connect to\n" \
     "                              simultaneously. Some Metalinks regulate the\n" \
@@ -361,7 +365,8 @@
     "                              if you don't have any preferred protocol.")
 #define TEXT_FOLLOW_METALINK                                            \
   _(" --follow-metalink=true|false|mem If true or mem is specified, when a file\n" \
-    "                              whose suffix is .metalink or content type of\n" \
+    "                              whose suffix is .meta4 or .metalink, or content\n" \
+    "                              type of application/metalink4+xml or\n" \
     "                              application/metalink+xml is downloaded, aria2\n" \
     "                              parses it as a metalink file and downloads files\n" \
     "                              mentioned in it.\n"                  \
@@ -370,7 +375,7 @@
     "                              If false is specified, the action mentioned above\n" \
     "                              is not taken.")
 #define TEXT_METALINK_ENABLE_UNIQUE_PROTOCOL                            \
-  _(" --metalink-enable-unique-protocol=true|false If true is given and several\n" \
+  _(" --metalink-enable-unique-protocol[=true|false] If true is given and several\n" \
     "                              protocols are available for a mirror in a metalink\n" \
     "                              file, aria2 uses one of them.\n"     \
     "                              Use --metalink-preferred-protocol option to\n" \
@@ -385,7 +390,7 @@
     "                              \"#http\". If non-tag word is given, print the usage\n" \
     "                              for the options whose name includes that word.")
 #define TEXT_NO_CONF                                                    \
-  _(" --no-conf                    Disable loading aria2.conf file.")
+  _(" --no-conf[=true|false]       Disable loading aria2.conf file.")
 #define TEXT_CONF_PATH                                                  \
   _(" --conf-path=PATH             Change the configuration file path to PATH.")
 #define TEXT_STOP                                                       \
@@ -480,29 +485,14 @@
   _(" --check-certificate[=true|false] Verify the peer using certificates specified\n" \
     "                              in --ca-certificate option.")
 #define TEXT_NO_PROXY                                                   \
-  _(" --no-proxy=DOMAINS           Specify comma separated hostnames or domains where\n" \
+  _(" --no-proxy=DOMAINS           Specify comma separated hostnames, domains or\n" \
+    "                              network address with or without CIDR block where\n" \
     "                              proxy should not be used.")
 #define TEXT_USE_HEAD                                                   \
   _(" --use-head[=true|false]      Use HEAD method for the first request to the HTTP\n" \
     "                              server.")
 #define TEXT_EVENT_POLL                                                 \
   _(" --event-poll=POLL            Specify the method for polling events.")
-#define TEXT_XML_RPC_LISTEN_PORT                                        \
-  _(" --xml-rpc-listen-port=PORT   Specify a port number for XML-RPC server to listen\n" \
-    "                              to.")
-#define TEXT_ENABLE_XML_RPC                                             \
-  _(" --enable-xml-rpc[=true|false] Enable XML-RPC server.\n"           \
-    "                              It is strongly recommended to set username and\n" \
-    "                              password using --xml-rpc-user and --xml-rpc-passwd\n" \
-    "                              option. See also --xml-rpc-listen-port option.")
-#define TEXT_XML_RPC_MAX_REQUEST_SIZE                                   \
-  _(" --xml-rpc-max-request-size=SIZE Set max size of XML-RPC request. If aria2\n" \
-    "                              detects the request is more than SIZE bytes, it\n" \
-    "                              drops connection.")
-#define TEXT_XML_RPC_USER                               \
-  _(" --xml-rpc-user=USER          Set XML-RPC user.")
-#define TEXT_XML_RPC_PASSWD                                     \
-  _(" --xml-rpc-passwd=PASSWD      Set XML-RPC password.")
 #define TEXT_BT_EXTERNAL_IP                                             \
   _(" --bt-external-ip=IPADDRESS   Specify the external IP address to report to a\n" \
     "                              BitTorrent tracker. Although this function is\n" \
@@ -537,25 +527,31 @@
     "                              based on the response of tracker and the download\n" \
     "                              progress.")
 #define TEXT_ON_DOWNLOAD_COMPLETE                                       \
-  _(" --on-download-complete=COMMAND Set the command to be executed when download\n" \
-    "                              completes.\n"                        \
+  _(" --on-download-complete=COMMAND Set the command to be executed after download\n" \
+    "                              completed.\n"                        \
     "                              See --on-download-start option for the\n" \
     "                              requirement of COMMAND.\n"           \
     "                              See also --on-download-stop option.")
 #define TEXT_ON_DOWNLOAD_START                                          \
-  _(" --on-download-start=COMMAND  Set the command to be executed when download\n" \
-    "                              starts up. COMMAND must take just one argument and\n" \
-    "                              GID is passed to COMMAND as a first argument.")
+  _(" --on-download-start=COMMAND  Set the command to be executed after download\n" \
+    "                              got started. aria2 passes 3 arguments to COMMAND:\n" \
+    "                              GID, the nubmer of files and file path. See Event\n" \
+    "                              Hook in man page for more details.")
+#define TEXT_ON_DOWNLOAD_PAUSE                                          \
+  _(" --on-download-pause=COMMAND  Set the command to be executed after download\n" \
+    "                              was paused.\n"\
+    "                              See --on-download-start option for the\n" \
+    "                              requirement of COMMAND.")
 #define TEXT_ON_DOWNLOAD_ERROR                                          \
-  _(" --on-download-error=COMMAND  Set the command to be executed when download\n" \
-    "                              aborts due to error.\n"              \
+  _(" --on-download-error=COMMAND  Set the command to be executed after download\n" \
+    "                              aborted due to error.\n"              \
     "                              See --on-download-start option for the\n" \
     "                              requirement of COMMAND.\n"           \
     "                              See also --on-download-stop option.")
 #define TEXT_ON_DOWNLOAD_STOP                                           \
-  _(" --on-download-stop=COMMAND   Set the command to be executed when download\n" \
-    "                              stops. You can override the command to be executed\n" \
-    "                              for particular download result using\n" \
+  _(" --on-download-stop=COMMAND   Set the command to be executed after download\n" \
+    "                              stopped. You can override the command to be\n" \
+    "                              executed for particular download result using\n" \
     "                              --on-download-complete and --on-download-error. If\n" \
     "                              they are specified, command specified in this\n" \
     "                              option is not executed.\n"           \
@@ -565,10 +561,6 @@
   _(" --bt-stop-timeout=SEC        Stop BitTorrent download if download speed is 0 in\n" \
     "                              consecutive SEC seconds. If 0 is given, this\n" \
     "                              feature is disabled.")
-#define TEXT_XML_RPC_LISTEN_ALL                                         \
-  _(" --xml-rpc-listen-all[=true|false] Listen incoming XML-RPC requests on all\n" \
-    "                              network interfaces. If false is given, listen only\n" \
-    "                              on local loopback interface.")
 #define TEXT_BT_PRIORITIZE_PIECE                                        \
   _(" --bt-prioritize-piece=head[=SIZE],tail[=SIZE] Try to download first and last\n" \
     "                              pieces of each file first. This is useful for\n" \
@@ -634,3 +626,157 @@
   _(" --ftp-proxy-user=USER        Set user for --ftp-proxy option.")
 #define TEXT_FTP_PROXY_PASSWD                                           \
   _(" --ftp-proxy-passwd=PASSWD    Set password for --ftp-proxy option.")
+#define TEXT_REMOVE_CONTROL_FILE                \
+  _(" --remove-control-file[=true|false] Remove control file before download. Using\n" \
+    "                              with --allow-overwrite=true, download always\n" \
+    "                              starts from scratch. This will be useful for\n" \
+    "                              users behind proxy server which disables resume.")
+#define TEXT_ALWAYS_RESUME                      \
+  _(" --always-resume[=true|false] Always resume download. If true is given, aria2\n" \
+    "                              always tries to resume download and if resume is\n" \
+    "                              not possible, aborts download. If false is given,\n" \
+    "                              when all given URIs do not support resume or\n" \
+    "                              aria2 encounters N URIs which does not support\n" \
+    "                              resume (N is the value specified using\n"   \
+    "                              --max-resume-failure-tries option), aria2\n" \
+    "                              downloads file from scratch.\n"       \
+    "                              See --max-resume-failure-tries option.")
+#define TEXT_MAX_RESUME_FAILURE_TRIES                                   \
+  _(" --max-resume-failure-tries=N When used with --always-resume=false, aria2\n" \
+    "                              downloads file from scratch when aria2 detects N\n" \
+    "                              number of URIs that does not support resume. If N\n" \
+    "                              is 0, aria2 downloads file from scratch when all\n" \
+    "                              given URIs do not support resume.\n" \
+    "                              See --always-resume option.")
+#define TEXT_BT_TRACKER_TIMEOUT                                 \
+  _(" --bt-tracker-timeout=SEC     Set timeout in seconds.")
+#define TEXT_BT_TRACKER_CONNECT_TIMEOUT                                 \
+  _(" --bt-tracker-connect-timeout=SEC Set the connect timeout in seconds to\n" \
+    "                              establish connection to tracker. After the\n" \
+    "                              connection is established, this option makes no\n" \
+    "                              effect and --bt-tracker-timeout option is used\n" \
+    "                              instead.")
+#define TEXT_DHT_MESSAGE_TIMEOUT                \
+  _(" --dht-message-timeout=SEC    Set timeout in seconds.")
+#define TEXT_HTTP_ACCEPT_GZIP                   \
+  _(" --http-accept-gzip[=true|false] Send 'Accept: deflate, gzip' request header\n" \
+    "                              and inflate response if remote server responds\n" \
+    "                              with 'Content-Encoding: gzip' or\n"  \
+    "                              'Content-Encoding: deflate'.")
+#define TEXT_SAVE_SESSION                       \
+  _(" --save-session=FILE          Save error/unfinished downloads to FILE on exit.\n" \
+    "                              You can pass this output file to aria2c with -i\n" \
+    "                              option on restart. Please note that downloads\n" \
+    "                              added by aria2.addTorrent and aria2.addMetalink\n" \
+    "                              RPC method are not saved.")
+#define TEXT_MAX_CONNECTION_PER_SERVER          \
+  _(" -x, --max-connection-per-server=NUM The maximum number of connections to one\n" \
+    "                              server for each download.")
+#define TEXT_MIN_SPLIT_SIZE                     \
+  _(" -k, --min-split-size=SIZE    aria2 does not split less than 2*SIZE byte range.\n" \
+    "                              For example, let's consider downloading 20MiB\n" \
+    "                              file. If SIZE is 10M, aria2 can split file into 2\n" \
+    "                              range [0-10MiB) and [10MiB-20MiB) and download it\n" \
+    "                              using 2 sources(if --split >= 2, of course).\n" \
+    "                              If SIZE is 15M, since 2*15M > 20MiB, aria2 does\n" \
+    "                              not split file and download it using 1 source.\n" \
+    "                              You can append K or M(1K = 1024, 1M = 1024K).")
+#define TEXT_CONDITIONAL_GET                    \
+  _(" --conditional-get[=true|false] Download file only when the local file is older\n" \
+    "                              than remote file. Currently, this function has\n" \
+    "                              many limitations. See man page for details.")
+#define TEXT_ON_BT_DOWNLOAD_COMPLETE            \
+  _(" --on-bt-download-complete=COMMAND For BitTorrent, a command specified in\n" \
+    "                              --on-download-complete is called after download\n" \
+    "                              completed and seeding is over. On the other hand,\n" \
+    "                              this option sets the command to be executed after\n" \
+    "                              download completed but before seeding.\n" \
+    "                              See --on-download-start option for the\n" \
+    "                              requirement of COMMAND.")
+#define TEXT_ENABLE_ASYNC_DNS6                  \
+  _(" --enable-async-dns6[=true|false] Enable IPv6 name resolution in asynchronous\n" \
+    "                              DNS resolver. This option will be ignored when\n" \
+    "                              --async-dns=false.")
+#define TEXT_ENABLE_DHT6                        \
+  _(" --enable-dht6[=true|false]   Enable IPv6 DHT functionality.\n" \
+    "                              Use --dht-listen-port option to specify port\n" \
+    "                              number to listen on. See also --dht-listen-addr6\n" \
+    "                              option.")
+#define TEXT_DHT_LISTEN_ADDR6                   \
+  _(" --dht-listen-addr6=ADDR      Specify address to bind socket for IPv6 DHT. \n" \
+    "                              It should be a global unicast IPv6 address of the\n" \
+    "                              host.")
+#define TEXT_DHT_ENTRY_POINT6                   \
+  _(" --dht-entry-point6=HOST:PORT Set host and port as an entry point to IPv6 DHT\n" \
+    "                              network.")
+#define TEXT_DHT_FILE_PATH6                     \
+  _(" --dht-file-path6=PATH        Change the IPv6 DHT routing table file to PATH.")
+#define TEXT_BT_TRACKER                                                 \
+  _(" --bt-tracker=URI[,...]       Comma separated list of additional BitTorrent\n" \
+    "                              tracker's announce URI. These URIs are not\n" \
+    "                              affected by --bt-exclude-tracker option because\n" \
+    "                              they are added after URIs in --bt-exclude-tracker\n" \
+    "                              option are removed.")
+#define TEXT_BT_EXCLUDE_TRACKER                                         \
+  _(" --bt-exclude-tracker=URI[,...] Comma separated list of BitTorrent tracker's\n" \
+    "                              announce URI to remove. You can use special value\n" \
+    "                              '*' which matches all URIs, thus removes all\n" \
+    "                              announce URIs. When specifying '*' in shell\n" \
+    "                              command-line, don't forget to escape or quote it.\n" \
+    "                              See also --bt-tracker option.")
+#define TEXT_MAX_DOWNLOAD_RESULT                \
+  _(" --max-download-result=NUM    Set maximum number of download result kept in\n" \
+    "                              memory. The download results are completed/error/\n" \
+    "                              removed downloads. The download results are stored\n" \
+    "                              in FIFO queue and it can store at most NUM\n" \
+    "                              download results. When queue is full and new\n" \
+    "                              download result is created, oldest download result\n" \
+    "                              is removed from the front of the queue and new one\n" \
+    "                              is pushed to the back. Setting big number in this\n" \
+    "                              option may result high memory consumption after\n" \
+    "                              thousands of downloads. Specifying 0 means no\n" \
+    "                              download result is kept.")
+#define TEXT_ASYNC_DNS_SERVER                   \
+  _(" --async-dns-server=IPADDRESS[,...] Comma separated list of DNS server address\n" \
+    "                              used in asynchronous DNS resolver. Usually\n" \
+    "                              asynchronous DNS resolver reads DNS server\n" \
+    "                              addresses from /etc/resolv.conf. When this option\n" \
+    "                              is used, it uses DNS servers specified in this\n" \
+    "                              option instead of ones in /etc/resolv.conf. You\n" \
+    "                              can specify both IPv4 and IPv6 address. This\n" \
+    "                              option is useful when the system does not have\n" \
+    "                              /etc/resolv.conf and user does not have the\n" \
+    "                              permission to create it.")
+#define TEXT_ENABLE_RPC                                             \
+  _(" --enable-rpc[=true|false]    Enable JSON-RPC/XML-RPC server.\n"   \
+    "                              It is strongly recommended to set username and\n" \
+    "                              password using --rpc-user and --rpc-passwd\n" \
+    "                              option. See also --rpc-listen-port option.")
+#define TEXT_RPC_MAX_REQUEST_SIZE                                   \
+  _(" --rpc-max-request-size=SIZE  Set max size of JSON-RPC/XML-RPC request. If aria2\n" \
+    "                              detects the request is more than SIZE bytes, it\n" \
+    "                              drops connection.")
+#define TEXT_RPC_USER                               \
+  _(" --rpc-user=USER              Set JSON-RPC/XML-RPC user.")
+#define TEXT_RPC_PASSWD                                     \
+  _(" --rpc-passwd=PASSWD          Set JSON-RPC/XML-RPC password.")
+#define TEXT_RPC_LISTEN_ALL                                         \
+  _(" --rpc-listen-all[=true|false] Listen incoming JSON-RPC/XML-RPC requests on all\n" \
+    "                              network interfaces. If false is given, listen only\n" \
+    "                              on local loopback interface.")
+#define TEXT_RPC_LISTEN_PORT                                        \
+  _(" --rpc-listen-port=PORT       Specify a port number for JSON-RPC/XML-RPC server\n" \
+    "                              to listen to.")
+#define TEXT_ENABLE_XML_RPC                                             \
+  _(" --enable-xml-rpc[=true|false] Deprecated. Use --enable-rpc instead.")
+#define TEXT_XML_RPC_MAX_REQUEST_SIZE                                   \
+  _(" --xml-rpc-max-request-size=SIZE Deprecated. Use --rpc-max-request-size\n" \
+    "                              instead.")
+#define TEXT_XML_RPC_USER                               \
+  _(" --xml-rpc-user=USER          Deprecated. Use --rpc-user instead.")
+#define TEXT_XML_RPC_PASSWD                                     \
+  _(" --xml-rpc-passwd=PASSWD      Deprecated. Use --rpc-passwd instead.")
+#define TEXT_XML_RPC_LISTEN_ALL                                         \
+  _(" --xml-rpc-listen-all[=true|false] Deprecated. Use --rpc-listen-all instead.")
+#define TEXT_XML_RPC_LISTEN_PORT                                        \
+  _(" --xml-rpc-listen-port=PORT   Deprecated. Use --rpc-listen-port instead.")
